@@ -69,3 +69,5 @@ class CoreFeatureSchema(FeatureSchema):
     github_repository = fields.String(required=True, default="inetum-orleans/docker-devbox-ddb")
     check_updates = fields.Boolean(required=True, default=True)
     required_version = fields.String(required=False, allow_none=True, default=None)
+    release_asset_name = fields.String(required=False, allow_none=True,
+                                        default=None)  # default is set in feature _configure_defaults
